html.wait, html.wait * { cursor: wait !important; }

.toast-danger{
    color: #721c24;
    background-color: #f8d7da;
    border-color: #f5c6cb;
}

.toast-primary {
    color: #004085;
    background-color: #cce5ff;
    border-color: #b8daff;
}

.toast-secondary {
    color: #383d41;
    background-color: #e2e3e5;
    border-color: #d6d8db;
}

.toast-success {
    color: #155724;
    background-color: #d4edda;
    border-color: #c3e6cb;
}

.toast-warning {
    color: #856404;
    background-color: #fff3cd;
    border-color: #ffeeba;
}

.toast-info {
    color: #0c5460;
    background-color: #d1ecf1;
    border-color: #bee5eb;
}

.toast-light {
    color: #818182;
    background-color: #fefefe;
    border-color: #fdfdfe;
}

.toast-dark {
    color: #1b1e21;
    background-color: #d6d8d9;
    border-color: #c6c8ca;
}

div.ajax-tooltip {
    max-width: 600px;
    background-color: #fff;
    color: #444;
    border: 1px solid #aaa;
}

div.tooltip.show {
    opacity: 1;
}

.drag_highlight {
    background-color: #e5f3ff !important;
}

.relative_overflow {
    position: relative;
    overflow: hidden;
}

.upload-dropzone{
    background-color: #F0F0F0;
    border: 1px dashed #0f0f0f;
    display: flex;
    justify-content: center;
    align-items: center;
}

.file-upload-form {
    position: absolute;
    right: 0px;
    top: 0px;
    cursor: hand;
    font-size: 200px;
    opacity: 0;
}
